'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _propTypes = require('prop-types');

var _propTypes2 = _interopRequireDefault(_propTypes);

var _classnames2 = require('classnames');

var _classnames3 = _interopRequireDefault(_classnames2);

var _SvgIcon = require('../SvgIcon');

var _SvgIcon2 = _interopRequireDefault(_SvgIcon);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

var isSortable = function isSortable(prop, sortableKeys, haveData) {
  return sortableKeys.indexOf(prop) !== -1 && haveData;
};
var normalizeProp = function normalizeProp(prop) {
  return prop.replace(/([A-Z])/g, ' $1');
};
var createOnClick = function createOnClick(fn, prop, i) {
  return function (event) {
    return fn(prop, i);
  };
};

var DataHeader = function DataHeader(_ref) {
  var _classnames;

  var bottom = _ref.bottom,
      scrollable = _ref.scrollable,
      dataMock = _ref.dataMock,
      excludeKeys = _ref.excludeKeys,
      headerLabels = _ref.headerLabels,
      onIconClick = _ref.onIconClick,
      onSortClick = _ref.onSortClick,
      ascending = _ref.ascending,
      sortActive = _ref.sortActive,
      sortableKeys = _ref.sortableKeys,
      dataLength = _ref.dataLength,
      iconColor = _ref.iconColor,
      hideIcon = _ref.hideIcon,
      isAllSelected = _ref.isAllSelected,
      disableSelectAll = _ref.disableSelectAll;

  var keys = Object.keys(dataMock).filter(function (key) {
    return excludeKeys.indexOf(key) === -1;
  });

  return _react2.default.createElement(
    'div',
    {
      className: (0, _classnames3.default)('data-table-header', { bottom: bottom }, { scrollable: scrollable })
    },
    !hideIcon && _react2.default.createElement(
      'div',
      {
        className: (0, _classnames3.default)('data-table-header-cell-icon', (_classnames = {}, _defineProperty(_classnames, 'is-selected-' + iconColor, !disableSelectAll), _defineProperty(_classnames, 'is-selected', isAllSelected && !disableSelectAll), _defineProperty(_classnames, 'is-disabled', disableSelectAll), _classnames))
      },
      _react2.default.createElement(_SvgIcon2.default, {
        icon: isAllSelected && !disableSelectAll ? 'checkbox-marked' : 'checkbox-blank-outline',
        onClick: onIconClick
      })
    ),
    keys.map(function (prop, i) {
      return _react2.default.createElement(
        'div',
        {
          key: i,
          className: (0, _classnames3.default)('data-table-header-cell', {
            'is-sortable': isSortable(prop, sortableKeys, dataLength),
            'is-sortable-active': sortActive === i
          }),
          onClick: createOnClick(onSortClick, prop, i)
        },
        sortActive === i && _react2.default.createElement(_SvgIcon2.default, { icon: ascending ? 'arrow-up' : 'arrow-down' }),
        headerLabels[i] || normalizeProp(prop)
      );
    })
  );
};

DataHeader.propTypes = {
  bottom: _propTypes2.default.bool,
  scrollable: _propTypes2.default.bool,
  dataMock: _propTypes2.default.object,
  excludeKeys: _propTypes2.default.array,
  headerLabels: _propTypes2.default.array,
  onIconClick: _propTypes2.default.func,
  onSortClick: _propTypes2.default.func,
  ascending: _propTypes2.default.bool,
  sortActive: _propTypes2.default.number,
  sortableKeys: _propTypes2.default.array,
  dataLength: _propTypes2.default.number,
  iconColor: _propTypes2.default.string,
  hideIcon: _propTypes2.default.bool,
  isAllSelected: _propTypes2.default.bool,
  disableSelectAll: _propTypes2.default.bool
};

exports.default = DataHeader;